@@ -169,7 +169,7 @@ class Property(Generic[T], Descriptor[T]):
 
     def _class_get(self, cls: type[object]) -> T:
         if self.__class_getter:
-            self.__class_getter(cls)
+            return self.__class_getter(cls)
         raise self.AccessError
 
     def getter(self, f: Optional[Callable[[Any], T]]):
